@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 
 use strict;
-#use lib '../lib';
+use lib '../lib';
 use Continuity;
 
 Continuity->new->loop;
