@@ -15,7 +15,6 @@ $server->loop;
 
 sub main {
   my ($req) = @_;
-  $req->next; # Get the initial request
 
   my $username;
 
@@ -30,10 +29,9 @@ sub main {
         </head>
         <body>
           <form id=f>
-          <input type=text id=username name=username size=10 value="$username">
-          <input type=text id=message name=message size=50>
-          <input type=submit name="sendbutton" value="Send" id="sendbutton">
-          <span id=status></span>
+            <input type=text id=username name=username size=10 value="$username">
+            <input type=text id=message name=message size=50>
+            <input type=submit name="sendbutton" value="Send" id="sendbutton">
           </form>
           <br>
           <div id=log>$messages_html</div>
