@@ -4,6 +4,7 @@ use lib '../lib';
 use strict;
 use warnings;
 use Continuity;
+use Continuity::Inspector;
 
 my $server = new Continuity(
       port => 8080,
@@ -27,31 +28,6 @@ sub getNum {
   return $num;
 }
 
-sub peek {
-  my ($request) = @_;
-  while(1) {
-    my $sessions = $server->{mapper}->{sessions};
-    $request->print(sprintf "Session count: %d<br>\n", scalar keys %$sessions);
-    my $sess;
-    my $inspector = Inspector->new( callback => sub {
-      use PadWalker 'peek_my';
-      for my $i (1..100) { 
-print STDERR "bjork\n";
-        my $vars = peek_my($i) or last;
-        next unless exists $vars->{'$number'};
-        $request->print("$sess: secret number: ", ${ $vars->{'$number'} }, "<br>\n");
-        last;
-      }
-    });
-    foreach $sess (keys %$sessions) {
-      # next unless $sess =~ /^\.\./;
-      next if $sess =~ /peek/;  # don't try to peek on ourself.  that would be bad.
-      $inspector->inspect( $sessions->{$sess} );
-    }
-    $request->next;
-  }
-}
-
 sub main {
   my $request = shift;
 
@@ -89,47 +65,29 @@ sub main {
     $request->next;
 }}
 
-package Inspector;
-use Data::Dumper;
-use Coro::Event;
-
-sub new {
-  my $class = shift;
-  my %args = @_;
-  my $self = { 
-    peeks_pending => \my $peeks_pending, 
-    requester => $args{requester},
-    callback => $args{callback},
-  };
-  bless $self, $class;
-  return $self;
-}
-
-sub inspect {
-    my $self = shift;
-    my $queue = shift;
-    ${ $self->{peeks_pending} } = 1;
-    $queue->put($self);
-    my $var_watcher = Coro::Event->var( var => $self->{peeks_pending}, poll => 'w', );
-    while( ${ $self->{peeks_pending} } ) {
-print STDERR "spin\n";
-        $var_watcher->next;
-print STDERR "spun\n";
+sub peek {
+  my ($request) = @_;
+  while(1) {
+    my $sessions = $server->{mapper}->{sessions};
+    $request->print(sprintf "Session count: %d<br>\n", scalar keys %$sessions);
+    my $sess;
+    my $inspector = Inspector->new( callback => sub {
+      use PadWalker 'peek_my';
+      for my $i (1..100) { 
+print STDERR "bjork\n";
+        my $vars = peek_my($i) or last;
+        next unless exists $vars->{'$number'};
+        $request->print("$sess: secret number: ", ${ $vars->{'$number'} }, "<br>\n");
+        last;
+      }
+    });
+    foreach $sess (keys %$sessions) {
+      # next unless $sess =~ /^\.\./;
+      next if $sess =~ /peek/;  # don't try to peek on ourself.  that would be bad.
+      $inspector->inspect( $sessions->{$sess} );
     }
-    $var_watcher->stop;
-    $var_watcher->cancel;
-    return undef;
+    $request->next;
+  }
 }
 
-sub immediate {
-  my $self = shift;
-  my $requester = $self->{requester};
-  $self->{callback}->(requester => $requester); # XXX API?  pass $self and solidify?  or just pass a few vars?
-  ${ $self->{peeks_pending} } = 0;
-  return 1;
-}
-
-sub end_request { }
-
-1;
 
